package tech.nevets.codebadgerestapi;

import static spark.Spark.*;

public class Server {
    public static void main(String[] args) {
        path("/badge", () -> {
            before("/*");
            get("/version/*/:gitUrl/:org/:repo/:branch", (req, res) -> {
                switch (req.splat()[0]) {
                    case "gitea" -> {
                        return BadgeFactory.getVersionFromGitRepo(req.params(":gitUrl"), req.params(":org"), req.params(":repo"), req.params(":branch"));
                    }
                    case "github" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                    case "gitlab" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                    case "test" -> {
                        res.type("image/png");
                        String version = BadgeFactory.getVersionFromGitRepo(req.params(":gitUrl"), req.params(":org"), req.params(":repo"), req.params(":branch"));
                        return BadgeFactory.generateBadge("Version", version, BadgeColor.GREEN);
                    }
                }
                res.status(404);
                return "Not Found!";
            });

            get("/buildStatus/*/:ciUrl/:projectName", (req, res) -> {
                switch (req.splat()[0]) {
                    case "jenkins" -> {
                        return BadgeFactory.getLatestBuildStatusFromJenkins(req.params(":ciUrl"), req.params(":projectName"));
                    }
                    case "circleci" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                    case "teamcity" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                }
                res.status(404);
                return "Not Found!";
            });

            get("/latestSuccessfulVersion/*/:ciUrl/:projectName", (req, res) -> {
                switch (req.splat()[0]) {
                    case "jenkins" -> {
                        return BadgeFactory.getLatestSuccessfulVersionFromJenkins(req.params(":ciUrl"), req.params(":projectName"));
                    }
                    case "circleci" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                    case "teamcity" -> {
                        res.status(405);
                        return "Not yet Implemented!";
                    }
                }
                res.status(404);
                return "Not Found!";
            });
        });
    }
}
